<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hr">
<context>
    <name>BookmarksWidget</name>
    <message>
        <location filename="../forms/bookmarkswidget.ui" line="32"/>
        <source>Filter:</source>
        <translation>Filtar:</translation>
    </message>
</context>
<context>
    <name>FontDialog</name>
    <message>
        <location filename="../forms/fontdialog.ui" line="14"/>
        <location filename="../forms/fontdialog.ui" line="73"/>
        <source>Select Terminal Font</source>
        <translation>Odaberi font za terminal</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="32"/>
        <source>Font:</source>
        <translation>Font:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="42"/>
        <source>Size:</source>
        <translation>Veličina:</translation>
    </message>
    <message>
        <location filename="../forms/fontdialog.ui" line="59"/>
        <source>Preview</source>
        <translation>Pretprikaz</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.cpp" line="88"/>
        <source>Bookmarks</source>
        <translation>Knjižne oznake</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="190"/>
        <source>Press &quot;%1&quot; to see the terminal.</source>
        <translation>Za prikaz terminala pritisni „%1”.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="239"/>
        <source>&amp;Next Tab</source>
        <translation>&amp;Sljedeća kartica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="242"/>
        <source>&amp;Previous Tab</source>
        <translation>&amp;Prethodna kartica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="251"/>
        <source>Move Tab &amp;Left</source>
        <translation>Premjesti karticu na &amp;lijevo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="254"/>
        <source>Move Tab &amp;Right</source>
        <translation>Premjesti karticu na &amp;desno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="273"/>
        <source>Split Terminal &amp;Horizontally</source>
        <translation>Podijeli terminal &amp;vodoravno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="276"/>
        <source>Split Terminal &amp;Vertically</source>
        <translation>Podijeli terminal &amp;okomito</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="281"/>
        <source>&amp;Collapse Subterminal</source>
        <translation>S&amp;klopi podterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="232"/>
        <source>&amp;Clear Active Terminal</source>
        <translation>&amp;Izbriši aktivni terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="171"/>
        <source>Keep window open when it loses focus</source>
        <translation>Ostavi prozor otvorenim kad izgubi fokus</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="245"/>
        <source>&amp;Previous Tab in History</source>
        <translation>&amp;Prethodna kartica u povijesti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="248"/>
        <source>&amp;Next Tab in History</source>
        <translation>&amp;Sljedeća kartica u povijesti</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="259"/>
        <source>Tab</source>
        <translation>Kartica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="260"/>
        <source>Go to</source>
        <translation>Prijeđi na</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="284"/>
        <source>&amp;Top Subterminal</source>
        <translation>&amp;Gornji podterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="287"/>
        <source>&amp;Bottom Subterminal</source>
        <translation>&amp;Donji podterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="290"/>
        <source>L&amp;eft Subterminal</source>
        <translation>&amp;Lijevi podterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="293"/>
        <source>R&amp;ight Subterminal</source>
        <translation>D&amp;esni podterminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="300"/>
        <source>Copy &amp;Selection</source>
        <translation>Kopiraj o&amp;značeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="303"/>
        <source>Paste Clip&amp;board</source>
        <translation>Umetni među&amp;spremnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="306"/>
        <source>Paste S&amp;election</source>
        <translation>Umetni &amp;označeno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="309"/>
        <source>Zoom &amp;in</source>
        <translation>U&amp;većaj</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="312"/>
        <source>Zoom &amp;out</source>
        <translation>U&amp;manji</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="315"/>
        <source>Zoom rese&amp;t</source>
        <translation>Obnovi &amp;zumiranje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="320"/>
        <source>&amp;Find...</source>
        <translation>&amp;Nađi …</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="323"/>
        <source>Handle history...</source>
        <translation>Upravljaj poviješću …</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="331"/>
        <source>&amp;Save Session</source>
        <translation>&amp;Spremi sesiju</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="337"/>
        <source>&amp;Load Session</source>
        <translation>&amp;Učitaj sesiju</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="344"/>
        <source>&amp;Toggle Menu</source>
        <translation>U&amp;ključi/isključi izbornik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="349"/>
        <source>Rename session</source>
        <translation>Preimenuj sesiju</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="358"/>
        <source>&amp;New Tab</source>
        <translation>&amp;Nova kartica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="362"/>
        <source>New Tab From &amp;Preset</source>
        <translation>Nova kartica iz &amp;predloška</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="363"/>
        <source>1 &amp;Terminal</source>
        <translation>1 &amp;Terminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="365"/>
        <source>2 &amp;Horizontal Terminals</source>
        <translation>2 &amp;Vodoravni terminali</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="367"/>
        <source>2 &amp;Vertical Terminals</source>
        <translation>2 &amp;Okomiti terminali</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="369"/>
        <source>4 Terminal&amp;s</source>
        <translation>4 Terminal&amp;i</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="375"/>
        <source>&amp;Close Tab</source>
        <translation>Z&amp;atvori karticu</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="378"/>
        <source>&amp;New Window</source>
        <translation>&amp;Novi prozor</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="383"/>
        <source>&amp;Preferences...</source>
        <translation>&amp;Postavke …</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="387"/>
        <source>&amp;Quit</source>
        <translation>&amp;Zatvori</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="393"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Sakrij rubove prozora</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="411"/>
        <source>&amp;Show Tab Bar</source>
        <translation>P&amp;rikaži traku kartica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="419"/>
        <source>Fullscreen</source>
        <translation>Cjelokrenski prikaz</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="425"/>
        <source>Toggle Bookmarks</source>
        <translation>Uključi/isključi knjižne oznake</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="433"/>
        <source>&amp;Bottom</source>
        <translation>&amp;Dolje</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="434"/>
        <source>&amp;Top</source>
        <translation>&amp;Gore</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="435"/>
        <location filename="../mainwindow.cpp" line="471"/>
        <source>&amp;Right</source>
        <translation>D&amp;esno</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="436"/>
        <location filename="../mainwindow.cpp" line="472"/>
        <source>&amp;Left</source>
        <translation>&amp;Lijevo</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="454"/>
        <source>&amp;Tabs Layout</source>
        <translation>Raspored kar&amp;tica</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="470"/>
        <source>&amp;None</source>
        <translation>&amp;Ništa</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="488"/>
        <source>S&amp;crollbar Layout</source>
        <translation>Raspore&amp;d klizne trake</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="501"/>
        <source>&amp;BlockCursor</source>
        <translation>&amp;Pravokutnik</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="502"/>
        <source>&amp;UnderlineCursor</source>
        <translation>Pod&amp;vlaka</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="503"/>
        <source>&amp;IBeamCursor</source>
        <translation>&amp;Uspravna crta</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="520"/>
        <source>&amp;Keyboard Cursor Shape</source>
        <translation>Obli&amp;k pokazivača tipkovnice</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="624"/>
        <source>Exit QTerminal</source>
        <translation>Zatvori QTerminal</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="626"/>
        <source>Do not ask again</source>
        <translation>Nemoj ponovo pitati</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="634"/>
        <source>Are you sure you want to exit?</source>
        <translation>Stvarno želiš zatvoriti program?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="659"/>
        <source>About</source>
        <translation>Informacije</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="661"/>
        <source>A lightweight and powerful multiplatform terminal emulator</source>
        <translation>Mali ali moćan višeplatformski emulator terminala</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>Copyright (C) </source>
        <translation>Copyright (C) </translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="663"/>
        <source>2013-2022</source>
        <translation>2013. – 2022.</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="665"/>
        <source>LXQt Project</source>
        <translation>Projekt LXQt</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="667"/>
        <source>Development: </source>
        <translation>Razvoj: </translation>
    </message>
</context>
<context>
    <name>PropertiesDialog</name>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="14"/>
        <source>Terminal settings</source>
        <translation>Postavke terminala</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="21"/>
        <source>Appearance</source>
        <translation>Izgled</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="30"/>
        <location filename="../forms/propertiesdialog.ui" line="581"/>
        <source>Behavior</source>
        <translation>Ponašanje</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="39"/>
        <source>Shortcuts</source>
        <translation>Prečaci</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="48"/>
        <source>Dropdown</source>
        <translation>Padajući izbornik</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="57"/>
        <source>Bookmarks</source>
        <translation>Knjižne oznake</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="272"/>
        <source>Hide tab bar with only one tab</source>
        <translation>Sakrij traku kartica koja sadrži samo jednu karticu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="173"/>
        <source>Color scheme</source>
        <translation>Shema boja</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="199"/>
        <source>Scrollbar position</source>
        <translation>Mjesto klizne trake</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="463"/>
        <source>Start with preset:</source>
        <translation>Pokreni s predloškom rasporeda:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="299"/>
        <source>Show a border around the current terminal</source>
        <translation>Prikaži rub za trenutačni terminal</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="380"/>
        <source>Terminal transparency</source>
        <translation>Prozirnost terminala</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="354"/>
        <source>Application transparency</source>
        <translation>Prozirnost programa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="474"/>
        <source>None (single terminal)</source>
        <translation>Bez (jedan terminal)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="479"/>
        <source>2 terminals horizontally</source>
        <translation>2 terminala vodoravno</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="484"/>
        <source>2 terminals vertically</source>
        <translation>2 terminala okomito</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="489"/>
        <source>4 terminals</source>
        <translation>4 terminala</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="364"/>
        <location filename="../forms/propertiesdialog.ui" line="390"/>
        <source> %</source>
        <translation> %</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="127"/>
        <source>Font</source>
        <translation>Font</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="163"/>
        <source>&amp;Change...</source>
        <translation>&amp;Promijeni …</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="212"/>
        <source>Tabs position</source>
        <translation>Položaj kartica</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="186"/>
        <source>Widget style</source>
        <translation>Stil programčića</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="258"/>
        <source>Show the menu bar</source>
        <translation>Prikaži traku izbornika</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="225"/>
        <source>Cursor shape</source>
        <translation>Oblik pokazivača</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="316"/>
        <source>Change window title based on current terminal</source>
        <translation>Promijeni naslov prozora na osnovi trenutačnog terminala</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="323"/>
        <source>Change window icon based on current terminal</source>
        <translation>Promijeni ikonu prozora na osnovi trenutačnog terminala</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="337"/>
        <source>Enable bi-directional text support</source>
        <translation>Aktiviraj dvosmjerno pisanje</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="406"/>
        <source>Background image:</source>
        <translation>Slika pozadine:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="418"/>
        <source>Select</source>
        <translation>Odaberi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="330"/>
        <source>Show terminal size on resize</source>
        <translation>Prikaži veličinu terminala prilikom mijenjanja veličine</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="279"/>
        <source>Fixed tab width:</source>
        <translation>Fiksna širina kartica:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="289"/>
        <location filename="../forms/propertiesdialog.ui" line="507"/>
        <source>px</source>
        <translation>px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="306"/>
        <source>Show close button on each tab</source>
        <translation>Prikaži gumb za zatvaranje na svakoj kartici</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="497"/>
        <source>Terminal margin</source>
        <translation>Margine terminala</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="347"/>
        <source>Use box drawing characters contained in the font</source>
        <translation>Koristi grafičke znakove fonta</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="248"/>
        <source>Accelerators are activated by Alt and can interfere with the terminal.</source>
        <translation>Ubrzivači se aktiviraju pomoću tipke Alt i mogu ometati rad s terminalom.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="251"/>
        <source>No menu bar accelerator</source>
        <translation>Bez ubrzivača u traci izbornika</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="813"/>
        <source>Emulation</source>
        <translation>Emulacija</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="614"/>
        <source>Action after paste</source>
        <translation>Radnja nakon umetanja</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="644"/>
        <source>Confirm multiline paste</source>
        <translation>Potvrdi umetanje višestrukih redaka</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="651"/>
        <source>Trim trailing newlines in pasted text</source>
        <translation>Ukloni nove retke u umetnutom tekstu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="747"/>
        <source>Open new terminals in current working directory</source>
        <translation>Otvori nove terminale u trenutačnoj radnoj mapi</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="682"/>
        <source>Save Size when closing</source>
        <translation>Spremi veličinu prilikom zatvaranja</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="675"/>
        <source>Save Position when closing</source>
        <translation>Spremi položaj prilikom zatvaranja</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="668"/>
        <source>Ask for confirmation when closing</source>
        <translation>Zatraži potvrdu prilikom zatvaranja</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="594"/>
        <source>Unlimited history</source>
        <translation>Beskonačna povijest</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="587"/>
        <source>History size (in lines)</source>
        <translation>Veličina povijesti (broj redaka)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="627"/>
        <source>Default $TERM</source>
        <translation>Standardni $TERMINAL</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="694"/>
        <source>Start with this size:</source>
        <translation>Pokreni s ovom veličinom:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="427"/>
        <source>Background mode:</source>
        <translation>Način prikaza pozadine:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="435"/>
        <source>None</source>
        <translation>Ništa</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="440"/>
        <source>Stretch</source>
        <translation>Razvučeno</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="445"/>
        <source>Zoom</source>
        <translation>Uvećano</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="450"/>
        <source>Fit</source>
        <translation>Prilagođeno</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="455"/>
        <source>Center</source>
        <translation>Centrirano</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="344"/>
        <source>Specify whether box drawing characters should be drawn by QTerminal internally or left to underlying font rendering libraries.</source>
        <translation>Odredi, treba li QTerminal crtati znakove za crtanje okvira interno ili pomoću osnovnih biblioteka za prikazivanje fontova.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="238"/>
        <source>Toggles usage of bold font face for rendering intense colors</source>
        <translation>Uključuje/isključuje upotrebu podebljanog fonta za prikaz intenzivnih boja</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="241"/>
        <source>Use bold font face for intense colors</source>
        <translation>Koristi podebljani font za intenzivne boje</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="265"/>
        <source>&amp;Hide Window Borders</source>
        <translation>&amp;Sakrij rubove prozora</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="822"/>
        <source>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Which behavior to emulate. Note that this does not have to match your operating system.&lt;/p&gt;&lt;p&gt;If you are not sure, use the &lt;span style=&quot; font-weight:600;&quot;&gt;default&lt;/span&gt; emulation.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</source>
        <translation>&lt;html&gt;&lt;head/&gt;&lt;body&gt;&lt;p&gt;Koje ponašanje emulirati. Ovo ne mora odgovarati tvom operacijskom sustavu.&lt;/p&gt;&lt;p&gt;Kad u nedoumici, koristi &lt;span style=&quot;font-weight:600;&quot;&gt; standardnu&lt;/span&gt; emulaciju.&lt;/p&gt;&lt;/body&gt;&lt;/html&gt;</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="800"/>
        <source>This command will be run with an argument containing the file name of a tempfile containing the scrollback history</source>
        <translation>Ova će se naredba pokrenuti s argumentom koji sadrži ime privremene datoteke koja sadrži povijest</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="803"/>
        <source>Handle history command</source>
        <translation>Naredba za upravljanje poviješću</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="701"/>
        <location filename="../forms/propertiesdialog.ui" line="715"/>
        <source> px</source>
        <translation> px</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="722"/>
        <source>Get current size</source>
        <translation>Preuzmi trenutačnu veličinu</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="757"/>
        <source>Open new tab to the right of the active tab</source>
        <translation>Otvori novu karticu desno od aktivne kartice</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="754"/>
        <source>If unchecked the new tab will be opened as the rightmost tab</source>
        <translation>Ako nije označeno, nova će se kartica otvoriti kao krajnja desna kartica</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="658"/>
        <source>Close tab on middle-click</source>
        <translation>Zatvori karticu srednjom tipkom</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="637"/>
        <source>Forcefully disable bracketed paste mode</source>
        <translation>Prisilno deaktiviraj način umetanja teksta u zagradama</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="634"/>
        <source>Bracketed paste mode is useful for pasting multiline strings.</source>
        <translation>Način umetanja teksta u zagradama koristan je za umetanje višerednih nizova.</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="764"/>
        <source>Audible bell</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="846"/>
        <source>To edit a Shortcut:
1. Double-click its Key
2. Press the desired combination and release it
3. Click on a Shortcut or press Enter

To remove/disable a Shortcut, at point 2 press only a modifier (like Shift)</source>
        <translation>Za mijenjanje prečaca:
1. Dvaput pritisni njegovu tipku
2. Pritisni željenu kombinaciju i otpusti je
3. Pritisni prečac ili pritisni Enter

Za uklanjanje/deaktiviranje prečaca, u točki 2 pritisni samo modifikatorsku tipku (poput Shift)</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="876"/>
        <source>Shortcut</source>
        <translation>Prečac</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="881"/>
        <source>Key</source>
        <translation>Tipka</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="893"/>
        <source>Show on start</source>
        <translation>Prikaži pri pokretanju</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="900"/>
        <source>A lock button is shown on horizontal tab bar</source>
        <translation>Gumb za zaključavanje se prikazuje na vodoravnoj traci kartica</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="903"/>
        <source>Keep window open when it loses focus</source>
        <translation>Ostavi prozor otvorenim kad izgubi fokus</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="910"/>
        <source>Size</source>
        <translation>Veličina</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="921"/>
        <source>Height</source>
        <translation>Visina</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="931"/>
        <location filename="../forms/propertiesdialog.ui" line="948"/>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="938"/>
        <source>Width</source>
        <translation>Širina</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="962"/>
        <source>Shortcut:</source>
        <translation>Prečac:</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1029"/>
        <source>Edit bookmark file contents</source>
        <translation>Uredi sadržaj datoteke knjižnih oznaka</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="988"/>
        <source>Enable bookmarks</source>
        <translation>Aktiviraj knjižne oznake</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="997"/>
        <source>Bookmark file</source>
        <translation>Datoteka knjižnih oznaka</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1010"/>
        <source>Find...</source>
        <translation>Pronađi …</translation>
    </message>
    <message>
        <location filename="../forms/propertiesdialog.ui" line="1019"/>
        <source>You can specify your own bookmarks file location. It allows easy bookmark sharing with tools like OwnCloud or Dropbox.</source>
        <translation>Moguće je odrediti vlastito mjesto datoteke knjižnih oznaka. To omogućuje jednostavno dijeljenje knjižnih oznaka s alatima poput OwnCloud ili Dropbox.</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <source>No scrollbar</source>
        <translation>Bez klizne trake</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Left</source>
        <translation>Lijevo</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="159"/>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Right</source>
        <translation>Desno</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Top</source>
        <translation>Gore</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="165"/>
        <source>Bottom</source>
        <translation>Dolje</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>BlockCursor</source>
        <translation>Pravokutnik</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>UnderlineCursor</source>
        <translation>Podvlaka</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="178"/>
        <source>IBeamCursor</source>
        <translation>Uspravna crta</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>No move</source>
        <translation>Bez premještanja</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to top</source>
        <translation>Klizanje skroz gore</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="196"/>
        <source>Scrolling to bottom</source>
        <translation>Klizanje skroz dolje</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="268"/>
        <source>Examples</source>
        <translation>Primjeri</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="421"/>
        <source>Images (*.bmp *.jpg *.png *.svg *.xpm)</source>
        <translation>Slike (*.bmp *.jpg *.png *.svg *.xpm)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="511"/>
        <source>Open bookmarks file</source>
        <translation>Otvori datoteku knjižnih oznaka</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="513"/>
        <source>XML files (*.xml)</source>
        <translation>XML datoteke (*.xml)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="514"/>
        <source>All files (*)</source>
        <translation>Sve datoteke (*)</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="613"/>
        <location filename="../propertiesdialog.cpp" line="617"/>
        <source>Question</source>
        <translation>Pitanje</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="613"/>
        <source>Do you want to overwrite this bookmarks file?</source>
        <translation>Želiš li prepisati ovu datoteku knjižnih oznaka?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="617"/>
        <source>The name of bookmarks file does not end with &apos;.xml&apos;.
Are you sure that you want to overwrite it?</source>
        <translation>Ime datoteke knjižnih oznaka ne završava s „.xml“.
Stvarno je želiš prepisati?</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="625"/>
        <source>Warning</source>
        <translation>Upozorenje</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="625"/>
        <source>Cannot write bookmarks to this file:</source>
        <translation>Nije moguće zapisati knjižne oznake u ovu datoteku:</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="203"/>
        <location filename="../propertiesdialog.cpp" line="317"/>
        <source>System Default</source>
        <translation>Standard sustava</translation>
    </message>
    <message>
        <location filename="../propertiesdialog.cpp" line="420"/>
        <source>Choose a background image</source>
        <translation>Odaberi sliku pozadine</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../bookmarkswidget.cpp" line="114"/>
        <source>Synchronized Bookmarks</source>
        <translation>Sinkroniziraj knjižne oznake</translation>
    </message>
</context>
<context>
    <name>TabWidget</name>
    <message>
        <location filename="../tabwidget.cpp" line="80"/>
        <location filename="../tabwidget.cpp" line="234"/>
        <source>Shell No. %1</source>
        <translation>Ljuska br. %1</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="202"/>
        <source>Tab name</source>
        <translation>Ime kartice</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="203"/>
        <source>New tab name:</source>
        <translation>Ime nove kartice:</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="223"/>
        <source>Select new tab title color</source>
        <translation>Odaberi boju naslova nove kartice</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="252"/>
        <source>Close session</source>
        <translation>Zatvori sesiju</translation>
    </message>
    <message>
        <location filename="../tabwidget.cpp" line="254"/>
        <source>Change title color</source>
        <translation>Promijeni boju naslova</translation>
    </message>
</context>
<context>
    <name>TermWidgetHolder</name>
    <message>
        <location filename="../termwidgetholder.cpp" line="79"/>
        <source>Load Session</source>
        <translation>Učitaj sesiju</translation>
    </message>
    <message>
        <location filename="../termwidgetholder.cpp" line="80"/>
        <source>List of saved sessions:</source>
        <translation>Popis spremljenih sesija:</translation>
    </message>
</context>
<context>
    <name>mainWindow</name>
    <message>
        <location filename="../forms/qterminal.ui" line="14"/>
        <source>MainWindow</source>
        <translation>Glavni prozor</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="59"/>
        <source>&amp;File</source>
        <translation>&amp;Datoteka</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="67"/>
        <source>&amp;Actions</source>
        <translation>&amp;Radnje</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="72"/>
        <source>&amp;Help</source>
        <translation>&amp;Pomoć</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="79"/>
        <source>&amp;View</source>
        <translation>Prika&amp;z</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="84"/>
        <source>&amp;Edit</source>
        <translation>&amp;Uredi</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="100"/>
        <source>&amp;About...</source>
        <translation>&amp;Informacije …</translation>
    </message>
    <message>
        <location filename="../forms/qterminal.ui" line="105"/>
        <source>About &amp;Qt...</source>
        <translation>&amp;Qt informacije …</translation>
    </message>
</context>
</TS>
